@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 require "pathname"
 
 module Bundler
@@ -71,10 +72,10 @@ module Bundler
         "bin/setup.tt" => "bin/setup"
       }
 
-      executables = %w(
+      executables = %w[
         bin/console
         bin/setup
-      )
+      ]
 
       templates.merge!("gitignore.tt" => ".gitignore") if Bundler.git_present?
 
